@@ -1,5 +1,5 @@
 /*
- *  ChkTeX v1.5, utility functions.
+ *  ChkTeX, utility functions.
  *  Copyright (C) 1995-96 Jens T. Berger Thielemann
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -32,10 +32,10 @@
 #include "OpSys.h"
 
 #ifdef ASM_HASHWORD
-extern UWORD HashWord(STRPTR a);
-typedef UWORD HASH_TYPE;
+extern unsigned short HashWord(const char *a);
+typedef unsigned short HASH_TYPE;
 #else
-typedef ULONG HASH_TYPE;
+typedef unsigned long HASH_TYPE;
 #endif
 
 /***************************** SUPPORT FUNCTIONS ************************/
@@ -49,21 +49,21 @@ typedef ULONG HASH_TYPE;
  */
 
 
-WORD substring(const STRPTR source, STRPTR dest, ULONG pos, LONG len)
+short substring(const char *source, char *dest, unsigned long pos, long len)
 {
-    STRPTR      Start;
-    WORD        Retval = -1;
+    const char *Start;
+    short Retval = -1;
 
-    if(len >= 0)
+    if (len >= 0)
     {
-        if(strlen(source) > pos)
+        if (strlen(source) > pos)
         {
             Start = &source[pos];
 
-            while((len-- > 0) && (*dest++ = *Start++))
+            while ((len-- > 0) && (*dest++ = *Start++))
                 ;
 
-            if(len == -1)
+            if (len == -1)
                 Retval = 0;
         }
     }
@@ -72,7 +72,7 @@ WORD substring(const STRPTR source, STRPTR dest, ULONG pos, LONG len)
 
     *dest = 0;
 
-    return(Retval);
+    return (Retval);
 }
 
 
@@ -82,16 +82,18 @@ WORD substring(const STRPTR source, STRPTR dest, ULONG pos, LONG len)
  */
 
 
-BOOL fexists(const STRPTR Filename)
+int fexists(const char *Filename)
 {
-    BOOL        Retval;
+    int Retval;
 
 #if defined(F_OK) && defined(R_OK) && defined(HAVE_ACCESS)
-    Retval = access(Filename, F_OK|R_OK) == 0;
-#else
-    FILE        *fh;
 
-    if(fh = fopen(Filename, "r"))
+    Retval = access(Filename, F_OK | R_OK) == 0;
+#else
+
+    FILE *fh;
+
+    if (fh = fopen(Filename, "r"))
     {
         Retval = TRUE;
         fclose(fh);
@@ -99,7 +101,8 @@ BOOL fexists(const STRPTR Filename)
     else
         Retval = FALSE;
 #endif
-    return(Retval);
+
+    return (Retval);
 }
 
 
@@ -113,15 +116,15 @@ BOOL fexists(const STRPTR Filename)
  * Returns `to' if some memset()'ing was done, NULL if not.
  */
 
-APTR sfmemset(APTR to, int c, LONG n)
+void *sfmemset(void *to, int c, long n)
 {
-    if(to && (n > 0))
+    if (to && (n > 0))
     {
         n = min(n, BUFSIZ);
 
-        return(memset(to, c, (size_t) n));
+        return (memset(to, c, (size_t) n));
     }
-    return(NULL);
+    return (NULL);
 }
 
 
@@ -130,14 +133,14 @@ APTR sfmemset(APTR to, int c, LONG n)
  * Replaces every occurrence of a character in a string with another one.
  */
 
-void strrep(STRPTR String,      /* String to replace within.    */
-            const TEXT From,   /* Character to search for.     */
-            const TEXT To)     /* Character to put instead.    */
+void strrep(char *String,       /* String to replace within.    */
+            const char From,    /* Character to search for.     */
+            const char To)      /* Character to put instead.    */
 {
     register int c;
-    while((c = *String++))
+    while ((c = *String++))
     {
-        if(c == From)
+        if (c == From)
             String[-1] = To;
     }
 }
@@ -146,17 +149,15 @@ void strrep(STRPTR String,      /* String to replace within.    */
  * Replaces every char not in Prot with To in Buf
  */
 
-void strxrep(STRPTR Buf,
-	     const STRPTR Prot,
-	     const TEXT To)
+void strxrep(char *Buf, const char *Prot, const char To)
 {
     int c;
 
-    while((c = *Buf))
+    while ((c = *Buf))
     {
-	if(!strchr(Prot, c))
-	    *Buf = To;
-	Buf++;
+        if (!strchr(Prot, c))
+            *Buf = To;
+        Buf++;
     }
 }
 
@@ -169,49 +170,53 @@ void strxrep(STRPTR Buf,
  */
 
 
-STRPTR strip(STRPTR str,                /* String to strip */
-             const enum Strip flags)
-    /* One of the following: */
-    /* STRP_LFT - Strips leading  blanks */
-    /* STRP_RGT - Strips trailing blanks */
-    /* STRP_BTH - Strips on both sides   */
+char *strip(char *str,          /* String to strip */
+            const enum Strip flags)
+/* One of the following: */
+/* STRP_LFT - Strips leading  blanks */
+/* STRP_RGT - Strips trailing blanks */
+/* STRP_BTH - Strips on both sides   */
 {
-    STRPTR bufptr = str, nlptr;
-    TEXT c;
+    char *bufptr = str;
+    char *nlptr;
+    char c;
 
-    if(bufptr && (c = *bufptr))
+    if (bufptr && (c = *bufptr))
     {
-        if(flags & STRP_LFT)
+        if (flags & STRP_LFT)
         {
-            if(LATEX_SPACE(c) && c)
+            if (LATEX_SPACE(c) && c)
             {
                 do
                 {
                     c = *++bufptr;
-                } while(LATEX_SPACE(c) && c);
+                }
+                while (LATEX_SPACE(c) && c);
             }
         }
 
-        if(flags & STRP_RGT)
+        if (flags & STRP_RGT)
         {
-            if(c && *bufptr)
+            if (c && *bufptr)
             {
                 nlptr = bufptr;
 
-                while(*++nlptr);
+                while (*++nlptr)
+                    ;
 
                 do
                 {
                     *nlptr = 0;
                     c = *--nlptr;
-                } while(LATEX_SPACE(c) && c && (nlptr > bufptr));
+                }
+                while (LATEX_SPACE(c) && c && (nlptr > bufptr));
 
             }
             else
                 *bufptr = 0;
         }
     }
-    return(bufptr);
+    return (bufptr);
 }
 
 
@@ -220,17 +225,15 @@ STRPTR strip(STRPTR str,                /* String to strip */
  */
 
 #ifndef HAVE_STRLWR
-STRPTR strlwr(STRPTR String)
+char *strlwr(char *String)
 {
-    STRPTR      Bufptr;
-    TEXT        TmpC;
+    char *Bufptr;
+    char TmpC;
 
-    for(Bufptr = String;
-        (TmpC = *Bufptr);
-        Bufptr++)
+    for (Bufptr = String; (TmpC = *Bufptr); Bufptr++)
         *Bufptr = tolower(TmpC);
 
-    return(String);
+    return (String);
 }
 #endif
 
@@ -239,19 +242,19 @@ STRPTR strlwr(STRPTR String)
  */
 
 #ifndef HAVE_STRDUP
-STRPTR strdup(const STRPTR String)
+char *strdup(const char *String)
 {
-    STRPTR      Retval = NULL;
-    size_t      Len;
+    char *Retval = NULL;
+    size_t Len;
 
-    if(String)
+    if (String)
     {
         Len = strlen(String) + 1;
-        if((Retval = malloc(Len)))
+        if ((Retval = malloc(Len)))
             memcpy(Retval, String, Len);
     }
 
-    return(Retval);
+    return (Retval);
 }
 #endif
 
@@ -259,19 +262,19 @@ STRPTR strdup(const STRPTR String)
  * Does the same as strdup, but adds a zero-filled padding, length extra bytes.
  */
 
-STRPTR strdupx(const STRPTR String, int Extra)
+char *strdupx(const char *String, int Extra)
 {
-    STRPTR      Retval = NULL;
-    size_t      Len;
+    char *Retval = NULL;
+    size_t Len;
 
-    if(String)
+    if (String)
     {
         Len = strlen(String) + 1 + Extra;
-        if((Retval = malloc(Len)))
+        if ((Retval = malloc(Len)))
             strncpy(Retval, String, Len);
     }
 
-    return(Retval);
+    return (Retval);
 }
 
 /*
@@ -279,18 +282,19 @@ STRPTR strdupx(const STRPTR String, int Extra)
  */
 
 #ifndef HAVE_STRCASECMP
-int strcasecmp(const char* a, const char *b)
+int strcasecmp(const char *a, const char *b)
 {
-  int aa, bb;
+    int aa, bb;
 
-  do
-  {
-      aa = *a++;
-      bb = *b++;
-  } while(aa && (tolower(aa) == tolower(bb)));
-  /* bb != 0 is implicit */
+    do
+    {
+        aa = *a++;
+        bb = *b++;
+    }
+    while (aa && (tolower(aa) == tolower(bb)));
+    /* bb != 0 is implicit */
 
-  return(tolower(aa) - tolower(bb));
+    return (tolower(aa) - tolower(bb));
 }
 #endif
 
@@ -301,19 +305,19 @@ int strcasecmp(const char* a, const char *b)
 
 void *saferealloc(void *b, size_t n)
 {
-  APTR  Retval = NULL;
+    void *Retval = NULL;
 
-  if(b)
-  {
-       if(n)
-          Retval = realloc(b, n);
-       else
-          free(b);
-  }
-  else
-      Retval = malloc(n);
+    if (b)
+    {
+        if (n)
+            Retval = realloc(b, n);
+        else
+            free(b);
+    }
+    else
+        Retval = malloc(n);
 
-  return(Retval);
+    return (Retval);
 }
 
 /*
@@ -321,33 +325,31 @@ void *saferealloc(void *b, size_t n)
  * Does nothing if passed empty/NULL string.
  */
 
-void strwrite (STRPTR To, const STRPTR From, ULONG Len)
+void strwrite(char *To, const char *From, unsigned long Len)
 {
-  ULONG i, j;
-  ULONG FromLen = strlen(From);
+    unsigned long i, j;
+    unsigned long FromLen = strlen(From);
 
-  Len = min(Len, BUFSIZ);
+    Len = min(Len, BUFSIZ);
 
-  if(To && From)
-  {
-      switch(FromLen)
-      {
-      case 0:
-          break;
-      case 1:
-          memset(To, *From, Len);
-          break;
-      default:
-          for(i = j = 0;
-              i < Len;
-              i++, j++)
-          {
-              if(j >= FromLen)
-                  j = 0;
-              To[i] = From[j];
-          }
-      }
-  }
+    if (To && From)
+    {
+        switch (FromLen)
+        {
+        case 0:
+            break;
+        case 1:
+            memset(To, *From, Len);
+            break;
+        default:
+            for (i = j = 0; i < Len; i++, j++)
+            {
+                if (j >= FromLen)
+                    j = 0;
+                To[i] = From[j];
+            }
+        }
+    }
 }
 
 /*
@@ -355,9 +357,9 @@ void strwrite (STRPTR To, const STRPTR From, ULONG Len)
  *
  */
 
-int strafter(const STRPTR Str, const STRPTR Cmp)
+int strafter(const char *Str, const char *Cmp)
 {
-    return(strncmp(Str, Cmp, strlen(Cmp)));
+    return (strncmp(Str, Cmp, strlen(Cmp)));
 }
 
 /*
@@ -365,22 +367,22 @@ int strafter(const STRPTR Str, const STRPTR Cmp)
  *
  */
 
-int strinfront(STRPTR Str, STRPTR Cmp)
+int strinfront(char *Str, char *Cmp)
 {
     int CmpLen;
 
-    if((CmpLen = strlen(Cmp)))
+    if ((CmpLen = strlen(Cmp)))
     {
         Cmp += CmpLen;
         Str++;
 
-        while((*--Cmp == *--Str) && (--CmpLen > 0))
+        while ((*--Cmp == *--Str) && (--CmpLen > 0))
             ;
 
-        return(CmpLen);
+        return (CmpLen);
     }
     else
-        return(1);
+        return (1);
 }
 
 
@@ -388,26 +390,26 @@ int strinfront(STRPTR Str, STRPTR Cmp)
 
 /*
  * Hashes a string. The string ought be rather short. We use an asm
- * version the Amiga; note that this returns an UWORD instead.
+ * version the Amiga; note that this returns an unsigned short instead.
  *
  * The algorithm was designed by Peter Weinberger. This version was
  * adapted from Dr Dobb's Journal April 1996 page 26.
  */
 
 #ifndef ASM_HASHWORD
-inline static ULONG HashWord(STRPTR str)
+static unsigned long HashWord(const char *str)
 {
-    register ULONG h = 0, hbit, c;
+    register unsigned long h = 0, hbit, c;
 
-    while((c = *str++))
+    while ((c = *str++))
     {
-        h = (h<<4) ^ c;
-        if((hbit = h & 0xf0000000))
-            h ^= hbit>>24;
-	h &= ~hbit;
+        h = (h << 4) ^ c;
+        if ((hbit = h & 0xf0000000))
+            h ^= hbit >> 24;
+        h &= ~hbit;
     }
 
-    return(h);
+    return (h);
 }
 #endif
 
@@ -416,19 +418,19 @@ inline static ULONG HashWord(STRPTR str)
  * duplicate the string yourself.
  */
 
-inline void InsertHash(const STRPTR a, struct Hash *h)
+void InsertHash(const char *a, struct Hash *h)
 {
     struct HashEntry **he, *newhe;
 
-    if(!h->Index)
+    if (!h->Index)
     {
-        ifn((h->Index = calloc(HASH_SIZE, sizeof(struct HashEntry *))))
+        if (!((h->Index = calloc(HASH_SIZE, sizeof(struct HashEntry *)))))
             PrintPrgErr(pmWordListErr);
     }
 
     he = &h->Index[HashWord(a) % HASH_SIZE];
 
-    if((newhe = malloc(sizeof(struct HashEntry))))
+    if ((newhe = malloc(sizeof(struct HashEntry))))
     {
         newhe->Next = *he;
         newhe->Str = a;
@@ -443,23 +445,29 @@ inline void InsertHash(const STRPTR a, struct Hash *h)
  * hash index.
  */
 
-inline STRPTR HasHash(const STRPTR a, const struct Hash *h)
+const char *HasHash(const char *a, const struct Hash *h)
 {
-     struct HashEntry *he;
-     HASH_TYPE i; /* Special magic to optimize SAS/C */
+    struct HashEntry *he;
+    HASH_TYPE i;                /* Special magic to optimize SAS/C */
 
-     i = HashWord(a);
-     i %= HASH_SIZE;
-     he = h->Index[i];
+    /* Do we have a hash? */
+    if (!h->Index)
+        return NULL;
 
-     while(he)
-     {
-        if(!strcmp(he->Str, a))
-            return(he->Str);
+    /* Find entry in hash */
+    i = HashWord(a);
+    i %= HASH_SIZE;
+    he = h->Index[i];
+
+    /* Search in the entry for the item */
+    while (he)
+    {
+        if (!strcmp(he->Str, a))
+            return (he->Str);
         else
             he = he->Next;
-     }
-     return(NULL);
+    }
+    return (NULL);
 }
 
 /*
@@ -468,7 +476,7 @@ inline STRPTR HasHash(const STRPTR a, const struct Hash *h)
 
 void ClearHash(struct Hash *h)
 {
-    if(h && h->Index)
+    if (h && h->Index)
         memset(h->Index, '\0', HASH_SIZE * sizeof(struct HashEntry *));
 }
 
@@ -480,11 +488,10 @@ void ClearHash(struct Hash *h)
 
 static void ReHash(struct WordList *WL)
 {
-    ULONG i = 0;
+    unsigned long i = 0;
 
     ClearHash(&WL->Hash);
-    FORWL(i, *WL)
-        InsertHash(WL->Stack.Data[i], &WL->Hash);
+    FORWL(i, *WL) InsertHash(WL->Stack.Data[i], &WL->Hash);
 }
 
 /*************************** WORDLIST HANDLING **************************/
@@ -494,27 +501,27 @@ static void ReHash(struct WordList *WL)
  * not need to make a duplicate of `Word' yourself.
  */
 
-BOOL InsertWord(const STRPTR Word, struct WordList *WL)
+int InsertWord(const char *Word, struct WordList *WL)
 {
-    STRPTR      WrdCpy;
-    ULONG       Len;
+    char *WrdCpy;
+    unsigned long Len;
 
-    if((WrdCpy = strdupx(Word, WALLBYTES)))
+    if ((WrdCpy = strdupx(Word, WALLBYTES)))
     {
-        if(StkPush(WrdCpy, &WL->Stack))
+        if (StkPush(WrdCpy, &WL->Stack))
         {
             Len = strlen(Word);
-            if(WL->MaxLen < Len)
+            if (WL->MaxLen < Len)
                 WL->MaxLen = Len;
 
             InsertHash(WrdCpy, &WL->Hash);
-            return(TRUE);
+            return (TRUE);
         }
 
         free(WrdCpy);
     }
 
-    return(FALSE);
+    return (FALSE);
 }
 
 /*
@@ -523,13 +530,13 @@ BOOL InsertWord(const STRPTR Word, struct WordList *WL)
 
 void ClearWord(struct WordList *WL)
 {
-    if(WL)
+    if (WL)
     {
         WL->Stack.Used = 0;
         WL->MaxLen = 0;
         ClearHash(&WL->Hash);
-        if(WL->NonEmpty)
-             InsertWord("", WL);
+        if (WL->NonEmpty)
+            InsertWord("", WL);
     }
 }
 
@@ -541,9 +548,9 @@ void ClearWord(struct WordList *WL)
  */
 
 
-STRPTR HasWord(const STRPTR Word, struct WordList *WL)
+const char *HasWord(const char *Word, struct WordList *WL)
 {
-    return(HasHash(Word, &WL->Hash));
+    return (HasHash(Word, &WL->Hash));
 }
 
 /*
@@ -553,9 +560,8 @@ STRPTR HasWord(const STRPTR Word, struct WordList *WL)
 
 void MakeLower(struct WordList *wl)
 {
-    ULONG i;
-    FORWL(i, *wl)
-	strlwr(wl->Stack.Data[i]);
+    unsigned long i;
+    FORWL(i, *wl) strlwr(wl->Stack.Data[i]);
     ReHash(wl);
 }
 
@@ -563,11 +569,10 @@ void MakeLower(struct WordList *wl)
  * Calls strrep on each argument in a list.
  */
 
-void ListRep(struct WordList *wl, const TEXT From, const TEXT To)
+void ListRep(struct WordList *wl, const char From, const char To)
 {
-    ULONG i;
-    FORWL(i, *wl)
-	strrep(wl->Stack.Data[i], From, To);
+    unsigned long i;
+    FORWL(i, *wl) strrep(wl->Stack.Data[i], From, To);
     ReHash(wl);
 }
 
@@ -580,32 +585,32 @@ void ListRep(struct WordList *wl, const TEXT From, const TEXT To)
  * Note: You can not push a NULL Data element.
  */
 
-BOOL StkPush(const APTR Data, struct Stack *Stack)
+int StkPush(void *Data, struct Stack *Stack)
 {
-    ULONG       NewSize;
-    APTR        *NewBuf;
+    unsigned long NewSize;
+    void **NewBuf;
 
-    if(Data && Stack)
+    if (Data && Stack)
     {
-        if(Stack->Used >= Stack->Size)
+        if (Stack->Used >= Stack->Size)
         {
             NewSize = Stack->Size + MINPUDDLE;
 
-            if((NewBuf = saferealloc(Stack->Data,
-                (size_t) NewSize * sizeof(APTR))))
+            if ((NewBuf = saferealloc(Stack->Data,
+                                      (size_t) NewSize * sizeof(void *))))
             {
                 Stack->Size = NewSize;
                 Stack->Data = NewBuf;
             }
             else
-                return(FALSE);
+                return (FALSE);
         }
 
         Stack->Data[Stack->Used++] = Data;
-        return(TRUE);
+        return (TRUE);
     }
 
-    return(FALSE);
+    return (FALSE);
 }
 
 /*
@@ -613,26 +618,27 @@ BOOL StkPush(const APTR Data, struct Stack *Stack)
  *
  */
 
-inline APTR StkPop(struct Stack *Stack)
+void *StkPop(struct Stack *Stack)
 {
-    APTR    Retval = NULL;
+    void *Retval = NULL;
 
-    if(Stack && (Stack->Used > 0))
+    if (Stack && (Stack->Used > 0))
     {
         Retval = Stack->Data[--Stack->Used];
 
 #ifdef NO_DIRTY_TRICKS
-        {
-            APTR        *NewBuf;
 
-            if(Stack->Used < (Stack->Size/2))
+        {
+            void **NewBuf;
+
+            if (Stack->Used < (Stack->Size / 2))
             {
-                ULONG   NewSize;
+                unsigned long NewSize;
                 NewSize = Stack->Size - MINPUDDLE;
                 NewSize = max(NewSize, MINPUDDLE);
 
-                if(NewBuf = saferealloc(Stack->Data,
-                   (size_t) NewSize * sizeof(APTR)))
+                if (NewBuf = saferealloc(Stack->Data,
+                                         (size_t) NewSize * sizeof(void *)))
                 {
                     Stack->Size = NewSize;
                     Stack->Data = NewBuf;
@@ -640,59 +646,59 @@ inline APTR StkPop(struct Stack *Stack)
             }
         }
 #endif
+
     }
-    return(Retval);
+    return (Retval);
 }
 
 /*
  * Returns the topmost element of the stack.
  */
 
-inline APTR StkTop(struct Stack *Stack)
+void *StkTop(struct Stack *Stack)
 {
-    if(Stack && (Stack->Used > 0))
-        return(Stack->Data[Stack->Used - 1]);
+    if (Stack && (Stack->Used > 0))
+        return (Stack->Data[Stack->Used - 1]);
     else
-        return(NULL);
+        return (NULL);
 }
 
 /****************************** INPUT STACK *****************************/
 
-BOOL PushFileName(const STRPTR Name, struct Stack *stack)
+int PushFileName(const char *Name, struct Stack *stack)
 {
-    FILE        *fh = NULL;
-    static 
-        TEXT NameBuf [BUFSIZ];
+    FILE *fh = NULL;
+    static char NameBuf[BUFSIZ];
 
-    if(Name && stack)
+    if (Name && stack)
     {
-        if(LocateFile(Name, NameBuf, ".tex", &TeXInputs))
+        if (LocateFile(Name, NameBuf, ".tex", &TeXInputs))
         {
-            if((fh = fopen(NameBuf, "r")))
+            if ((fh = fopen(NameBuf, "r")))
             {
-                return(PushFile(NameBuf, fh, stack));
+                return (PushFile(NameBuf, fh, stack));
             }
         }
         PrintPrgErr(pmNoTeXOpen, Name);
     }
-    return(FALSE);
+    return (FALSE);
 }
 
 
-BOOL PushFile(STRPTR Name, FILE *fh, struct Stack *stack)
+int PushFile(char *Name, FILE * fh, struct Stack *stack)
 {
-    struct FileNode     *fn;
+    struct FileNode *fn;
 
-    if(Name && fh && stack)
+    if (Name && fh && stack)
     {
-        if((fn = malloc(sizeof(struct FileNode))))
+        if ((fn = malloc(sizeof(struct FileNode))))
         {
-            if((fn->Name = strdup(Name)))
+            if ((fn->Name = strdup(Name)))
             {
                 fn->fh = fh;
                 fn->Line = 0L;
-                if(StkPush(fn, stack))
-                    return(TRUE);
+                if (StkPush(fn, stack))
+                    return (TRUE);
                 free(fn->Name);
             }
             free(fn);
@@ -700,19 +706,19 @@ BOOL PushFile(STRPTR Name, FILE *fh, struct Stack *stack)
         PrintPrgErr(pmNoStackMem);
     }
 
-    return(FALSE);
+    return (FALSE);
 }
 
-STRPTR FGetsStk(STRPTR Dest, ULONG len, struct Stack *stack)
+char *FGetsStk(char *Dest, unsigned long len, struct Stack *stack)
 {
-    struct FileNode     *fn;
-    STRPTR Retval = NULL;
+    struct FileNode *fn;
+    char *Retval = NULL;
 
-    if((fn = StkTop(stack)))
+    if ((fn = StkTop(stack)))
     {
         do
         {
-            if((Retval = fgets(Dest, (int) len, fn->fh))) 
+            if ((Retval = fgets(Dest, (int) len, fn->fh)))
             {
                 fn->Line++;
                 break;
@@ -722,50 +728,49 @@ STRPTR FGetsStk(STRPTR Dest, ULONG len, struct Stack *stack)
             fclose(fn->fh);
             free(fn);
 
-        } while(!Retval && (fn = StkTop(stack)));
+        }
+        while (!Retval && (fn = StkTop(stack)));
     }
 
-    return(Retval);
+    return (Retval);
 }
 
-STRPTR CurStkName(struct Stack *stack)
+char *CurStkName(struct Stack *stack)
 {
-    struct FileNode     *fn;
-    static
-        STRPTR  LastName = "";
+    struct FileNode *fn;
+    static char *LastName = "";
 
-    if(PseudoInName && (stack->Used <= 1))
-      return(PseudoInName);
+    if (PseudoInName && (stack->Used <= 1))
+        return (PseudoInName);
     else
     {
-        if((fn = StkTop(stack)))
-            return(LastName = fn->Name);
+        if ((fn = StkTop(stack)))
+            return (LastName = fn->Name);
         else
-            return(LastName);
+            return (LastName);
     }
 }
 
 
-FILE *CurStkFile(struct Stack *stack)
+FILE *CurStkFile(struct Stack * stack)
 {
-    struct FileNode     *fn;
+    struct FileNode *fn;
 
-    if((fn = StkTop(stack)))
-        return(fn->fh);
+    if ((fn = StkTop(stack)))
+        return (fn->fh);
     else
-        return(NULL);
+        return (NULL);
 }
 
-ULONG CurStkLine(struct Stack *stack)
+unsigned long CurStkLine(struct Stack *stack)
 {
-    struct FileNode     *fn;
-    static
-        ULONG LastLine = 0L;
+    struct FileNode *fn;
+    static unsigned long LastLine = 0L;
 
-    if((fn = StkTop(stack)))
-        return(LastLine = fn->Line);
+    if ((fn = StkTop(stack)))
+        return (LastLine = fn->Line);
     else
-        return(LastLine);
+        return (LastLine);
 }
 
 
@@ -776,26 +781,28 @@ ULONG CurStkLine(struct Stack *stack)
  * Pushes the character on the stack.
  */
 
-struct ErrInfo *PushChar(const TEXT c, const ULONG Line,
-              const ULONG Column, struct Stack *Stk,
-              const STRPTR LineCpy)
+struct ErrInfo *PushChar(const char c, const unsigned long Line,
+                         const unsigned long Column, struct Stack *Stk,
+                         const char *LineCpy)
 {
-    TEXT       Buf[2];
+    char Buf[2];
 
-    Buf[0] = c; Buf[1] = 0;
+    Buf[0] = c;
+    Buf[1] = 0;
 
-    return(PushErr( Buf, Line, Column, 1,  LineCpy, Stk));
+    return (PushErr(Buf, Line, Column, 1, LineCpy, Stk));
 }
 
-struct ErrInfo *PushErr(const STRPTR Data, const ULONG Line,
-             const ULONG Column, const ULONG ErrLen,
-             const STRPTR LineCpy, struct Stack *Stk)
+struct ErrInfo *PushErr(const char *Data, const unsigned long Line,
+                        const unsigned long Column,
+                        const unsigned long ErrLen, const char *LineCpy,
+                        struct Stack *Stk)
 {
-    struct ErrInfo      *ci;
+    struct ErrInfo *ci;
 
-    if((ci = malloc(sizeof(struct ErrInfo))))
+    if ((ci = malloc(sizeof(struct ErrInfo))))
     {
-        if((ci->Data = strdup(Data)))
+        if ((ci->Data = strdup(Data)))
         {
             ci->File = CurStkName(&InputStack);
             ci->Line = Line;
@@ -804,15 +811,15 @@ struct ErrInfo *PushErr(const STRPTR Data, const ULONG Line,
             ci->LineBuf = LineCpy;
             ci->Flags = efNone;
 
-            if(StkPush(ci, Stk))
-                return(ci);
+            if (StkPush(ci, Stk))
+                return (ci);
         }
         else
             PrintPrgErr(pmStrDupErr);
         free(ci);
     }
 
-    return(NULL);
+    return (NULL);
 }
 
 /*
@@ -820,25 +827,23 @@ struct ErrInfo *PushErr(const STRPTR Data, const ULONG Line,
  * String.
  */
 
-struct ErrInfo *TopMatch(struct Stack *Stack, STRPTR String)
+struct ErrInfo *TopMatch(struct Stack *Stack, char *String)
 {
     int i;
     struct ErrInfo *retval = NULL;
 
-    if(Stack && String)
+    if (Stack && String)
     {
-        for(i = Stack->Used - 1;
-            i >= 0;
-            i--)
-        {    
-            if(!strcmp(String, ((struct ErrInfo *) Stack->Data[i])->Data))
+        for (i = Stack->Used - 1; i >= 0; i--)
+        {
+            if (!strcmp(String, ((struct ErrInfo *) Stack->Data[i])->Data))
             {
                 retval = (struct ErrInfo *) Stack->Data[i];
                 break;
             }
         }
     }
-    return(retval);
+    return (retval);
 }
 
 /*
@@ -849,7 +854,7 @@ struct ErrInfo *TopMatch(struct Stack *Stack, STRPTR String)
 
 struct ErrInfo *PopErr(struct Stack *Stack)
 {
-    return((struct ErrInfo *) StkPop(Stack));
+    return ((struct ErrInfo *) StkPop(Stack));
 }
 
 /*
@@ -859,17 +864,18 @@ struct ErrInfo *PopErr(struct Stack *Stack)
 
 struct ErrInfo *TopErr(struct Stack *Stack)
 {
-    return((struct ErrInfo *) StkTop(Stack));
+    return ((struct ErrInfo *) StkTop(Stack));
 }
 
 /*
  * Free all resources associated with a struct FreeInfo.
  */
 
-void FreeErrInfo(struct ErrInfo* ei)
+void FreeErrInfo(struct ErrInfo *ei)
 {
-    if(ei) {
-        if(ei->Data)
+    if (ei)
+    {
+        if (ei->Data)
             free(ei->Data);
 
         free(ei);
@@ -884,24 +890,24 @@ void FreeErrInfo(struct ErrInfo* ei)
  * BrOrder array. Returns ~0 if the character was not a bracket.
  */
 
-LONG BrackIndex(const TEXT c)
+long BrackIndex(const char c)
 {
-    switch(c)
+    switch (c)
     {
     case '(':
-        return(0);
+        return (0);
     case ')':
-        return(1);
+        return (1);
     case '[':
-        return(2);
+        return (2);
     case ']':
-        return(3);
+        return (3);
     case '{':
-        return(4);
+        return (4);
     case '}':
-        return(5);
+        return (5);
     default:
-        return(~0L);
+        return (~0L);
     }
 }
 
@@ -910,11 +916,11 @@ LONG BrackIndex(const TEXT c)
  * corresponding counter.
  */
 
-void AddBracket(const TEXT c)
+void AddBracket(const char c)
 {
-    LONG        Index;
+    long Index;
 
-    if((Index = BrackIndex(c)) != -1)
+    if ((Index = BrackIndex(c)) != -1)
         Brackets[Index]++;
 
 }
@@ -924,14 +930,14 @@ void AddBracket(const TEXT c)
  * wasn't a bracket character.
  */
 
-TEXT MatchBracket(const TEXT c)
+char MatchBracket(const char c)
 {
-    ULONG       Index;
-    TEXT        Char = 0;
+    unsigned long Index;
+    char Char = 0;
 
 
-    if((Index = BrackIndex(c)) != ~0UL)
+    if ((Index = BrackIndex(c)) != ~0UL)
         Char = BrOrder[Index ^ 1];
 
-    return(Char);
+    return (Char);
 }
